pub enum InventoryResponse<A, M> {
Available(A),
Missing(M),
}Expand description
A generic peer inventory response status.
Available is used for inventory that is present in the response,
and Missing is used for inventory that is missing from the response.
Variants
Implementations
Sourceimpl InventoryResponse<(AtLeastOne<InventoryHash>, PeerSocketAddr), (AtLeastOne<InventoryHash>, PeerSocketAddr)>
impl InventoryResponse<(AtLeastOne<InventoryHash>, PeerSocketAddr), (AtLeastOne<InventoryHash>, PeerSocketAddr)>
Sourcepub fn new_available(hash: InventoryHash, peer: PeerSocketAddr) -> Self
pub fn new_available(hash: InventoryHash, peer: PeerSocketAddr) -> Self
Returns a new available inventory change from a single hash.
Sourcepub fn new_missing(hash: InventoryHash, peer: PeerSocketAddr) -> Self
pub fn new_missing(hash: InventoryHash, peer: PeerSocketAddr) -> Self
Returns a new missing inventory change from a single hash.
Sourcepub fn new_available_multi<'a>(
hashes: impl IntoIterator<Item = &'a InventoryHash>,
peer: PeerSocketAddr,
) -> Option<Self>
pub fn new_available_multi<'a>( hashes: impl IntoIterator<Item = &'a InventoryHash>, peer: PeerSocketAddr, ) -> Option<Self>
Returns a new available multiple inventory change, if hashes contains at least one change.
Sourcepub fn new_missing_multi<'a>(
hashes: impl IntoIterator<Item = &'a InventoryHash>,
peer: PeerSocketAddr,
) -> Option<Self>
pub fn new_missing_multi<'a>( hashes: impl IntoIterator<Item = &'a InventoryHash>, peer: PeerSocketAddr, ) -> Option<Self>
Returns a new missing multiple inventory change, if hashes contains at least one change.
Sourceimpl<T> InventoryResponse<T, T>
impl<T> InventoryResponse<T, T>
Sourcepub fn marker(&self) -> InventoryResponse<(), ()>
pub fn marker(&self) -> InventoryResponse<(), ()>
Get a marker for the status, without any associated data.
Sourcepub fn map<U, F: FnOnce(T) -> U>(self, f: F) -> InventoryResponse<U, U>
pub fn map<U, F: FnOnce(T) -> U>(self, f: F) -> InventoryResponse<U, U>
Maps an InventoryStatus<T> to InventoryStatus<U> by applying a function to a contained value.
Sourceimpl<T: Clone> InventoryResponse<T, T>
impl<T: Clone> InventoryResponse<T, T>
Sourceimpl<A, M> InventoryResponse<A, M>
impl<A, M> InventoryResponse<A, M>
Sourcepub fn is_available(&self) -> bool
pub fn is_available(&self) -> bool
Returns true if the inventory item was available.
Sourcepub fn is_missing(&self) -> bool
pub fn is_missing(&self) -> bool
Returns true if the inventory item was missing.
Sourcepub fn map_available<B, F: FnOnce(A) -> B>(
self,
f: F,
) -> InventoryResponse<B, M>
pub fn map_available<B, F: FnOnce(A) -> B>( self, f: F, ) -> InventoryResponse<B, M>
Sourcepub fn map_missing<N, F: FnOnce(M) -> N>(self, f: F) -> InventoryResponse<A, N>
pub fn map_missing<N, F: FnOnce(M) -> N>(self, f: F) -> InventoryResponse<A, N>
Sourcepub fn as_ref(&self) -> InventoryResponse<&A, &M>
pub fn as_ref(&self) -> InventoryResponse<&A, &M>
Converts from &InventoryResponse<A, M> to InventoryResponse<&A, &M>.